from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, String, Boolean, Array, File

Rnachipintegrator_V0_1_0 = CommandToolBuilder(tool="RnaChipIntegrator", base_command=["RnaChipIntegrator"], inputs=[ToolInput(tag="in_cut_off", input_type=Int(optional=True), prefix="--cutoff", doc=InputDocumentation(doc="Maximum distance allowed between peaks and genes\nbefore being omitted from the analyses (default\n1000000bp; set to zero for no cutoff, use --cutoffs\ninstead to specify multiple distances)")), ToolInput(tag="in_edge", input_type=String(optional=True), prefix="--edge", doc=InputDocumentation(doc="Gene edges to consider when calculating distances\nbetween genes and peaks, either: 'tss' (default: only\nuse gene TSS) or 'both' (use whichever of TSS or TES\ngives shortest distance)")), ToolInput(tag="in_only_de", input_type=Boolean(optional=True), prefix="--only-DE", doc=InputDocumentation(doc="Only use genes flagged as differentially expressed in\nanalyses (input gene data must include DE flags)")), ToolInput(tag="in_number", input_type=Int(optional=True), prefix="--number", doc=InputDocumentation(doc="Filter results after applying --cutoff[s] to report\nonly the nearest MAX_CLOSEST number of pairs for each\ngene/peak from the analyses (default is to report all\nresults)")), ToolInput(tag="in_promoter_region", input_type=Int(optional=True), prefix="--promoter_region", doc=InputDocumentation(doc="Define promoter region with respect to gene TSS in the\nform UPSTREAM,DOWNSTREAM (default -1000 to 100bp of\nTSS)")), ToolInput(tag="in_name", input_type=String(optional=True), prefix="--name", doc=InputDocumentation(doc="Set basename for output files")), ToolInput(tag="in_compact", input_type=Boolean(optional=True), prefix="--compact", doc=InputDocumentation(doc="Output all hits for each peak or gene on a single line\n(cannot be used with --summary)")), ToolInput(tag="in_summary", input_type=Boolean(optional=True), prefix="--summary", doc=InputDocumentation(doc="Output 'summary' for each analysis, consisting of only\nthe top hit for each peak or gene (cannot be used with\n--compact)")), ToolInput(tag="in_pad", input_type=Boolean(optional=True), prefix="--pad", doc=InputDocumentation(doc="Where less than MAX_CLOSEST hits are found, pad output\nwith blanks to ensure that MAX_CLOSEST hits are still\nreported (nb --pad is implied for --compact)")), ToolInput(tag="in_xls_x", input_type=Boolean(optional=True), prefix="--xlsx", doc=InputDocumentation(doc="Output XLSX spreadsheet with results")), ToolInput(tag="in_cutoffs", input_type=Int(optional=True), prefix="--cutoffs", doc=InputDocumentation(doc="Comma-separated list of one or more maximum distances\nallowed between peaks and genes (bp). An analysis will\nbe performed for each GENES-PEAKS pair at each cutoff\ndistance (default 1000000bp; set to zero for no cutoff\nNB cannot be used in conjunction with the --cutoff\noption)")), ToolInput(tag="in_specify_genes_files", input_type=Array(t=File(), optional=True), prefix="--genes", doc=InputDocumentation(doc="Specify multiple genes files (if used then peaks\nfile(s) must be specified using --peaks option)")), ToolInput(tag="in_specify_peaks_files", input_type=Array(t=File(), optional=True), prefix="--peaks", doc=InputDocumentation(doc="Specify multiple peaks files (if used then genes\nfile(s) must be specified using --genes option)")), ToolInput(tag="in_n_processors", input_type=Int(optional=True), prefix="--nprocessors", doc=InputDocumentation(doc="Number of processors/cores to run the program using\n(default: 1)")), ToolInput(tag="in_split_outputs", input_type=Boolean(optional=True), prefix="--split-outputs", doc=InputDocumentation(doc="In batch mode write results of each analysis to\nseparate file (default is to write all results to\nsingle file)")), ToolInput(tag="in_analyses", input_type=String(optional=True), prefix="--analyses", doc=InputDocumentation(doc="Select which analyses to run: can be one of 'all'\n(default, runs all available analyses), 'peak_centric'\nor 'gene_centric'")), ToolInput(tag="in_feature", input_type=String(optional=True), prefix="--feature", doc=InputDocumentation(doc="Rename 'gene' to FEATURE_TYPE in output (e.g.\n'transcript' etc)")), ToolInput(tag="in_peak_cols", input_type=File(optional=True), prefix="--peak_cols", doc=InputDocumentation(doc="List of 3 column indices (e.g. '1,4,5') indicating\ncolumns to use for chromosome, start and end from the\ninput peak file (if not first three columns)")), ToolInput(tag="in_peak_id", input_type=File(optional=True), prefix="--peak_id", doc=InputDocumentation(doc="Column to use as an ID for each peak from the input\npeak file (first column is column 1). If specified\nthen IDs will be transferred to the output files when\npeaks are reported\n")), ToolInput(tag="in_var_19", input_type=String(optional=True), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_20", input_type=String(optional=True), position=1, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Rnachipintegrator_V0_1_0().translate("wdl", allow_empty_container=True)

